pub enum P2pCommand {
Serve {
port: u16,
},
Connect {
peer: String,
},
}Variants
Serve
Start a lightweight local P2P git notes sync server on the local LAN
Connect
Pull and merge notes directly from a peer developer’s IP on the local Wi-Fi