Commands

Enum Commands 

pub enum Commands {
Show 18 variants Add(AddArgs), Reply(ReplyArgs), List(ListArgs), Show(ShowArgs), Sync(SyncArgs), Resolve(ResolveArgs), Export(ExportArgs), Doctor, Blame(BlameArgs), ImportPr(ImportPrArgs), Import(ImportArgs), Summarize(SummarizeArgs), Init, Hook(HookArgs), Diff(DiffArgs), Shortcuts(ShortcutsArgs), Completions(CompletionsArgs), RebaseHeal(RebaseHealArgs),
}

Variants



Add(AddArgs)

Add a new note [alias: a]



Reply(ReplyArgs)

Reply to an existing note thread [alias: r]



List(ListArgs)

List notes [aliases: l, ls]



Show(ShowArgs)

Show a specific note or thread [alias: s]



Sync(SyncArgs)

Sync notes with remote or offline peers [aliases: push, pull, p2p]



Resolve(ResolveArgs)

Resolve a note [aliases: ok, close]



Export(ExportArgs)

Export notes [alias: exp]



Doctor

Check repository health and configuration [alias: doc]



Blame(BlameArgs)

View git blame with inline notes [alias: b]



ImportPr(ImportPrArgs)

Import review comments from a GitHub Pull Request [alias: pr]



Import(ImportArgs)

Multi-provider importer for GitLab MRs, Bitbucket PRs, Jira issues, and GitHub [alias: imp]



Summarize(SummarizeArgs)

AI-powered summary of open discussion threads (Gemini) [alias: sum]



Init

Setup git hooks and remote tracking refspec in 1 second [alias: i]



Hook(HookArgs)

Manage git auto-sync hooks



Diff(DiffArgs)

View diff with inline notes attached to hunks [alias: d]



Shortcuts(ShortcutsArgs)

View and customize quickies, CLI abbreviations, and keyboard shortcuts [aliases: shortcut, keys, quickies]



Completions(CompletionsArgs)

Generate shell completions



RebaseHeal(RebaseHealArgs)

Automatically re-anchor notes after a git rebase, amend, or cherry-pick [alias: heal]